@@ -162,6 +162,15 @@ class DagTestCase(TestCase):
 
         # Test additional fields for edge
         self.assertEqual(b3.children.through.objects.filter(child=c1)[0].name, "b3 c1")
+        # ToDo: Fix Below
+        print(NetworkNode.objects.all())
+        print(NetworkEdge.objects.all())
+        print("root.ancestors_edges()", root.ancestors_edges())
+        self.assertEqual(b3.descendants_edges().first(), NetworkEdge.objects.get(parent=b3, child=c2))
+        # self.assertEqual(a1.ancestors_edges()[0], NetworkEdge.objects.get(parent=root, child=a1))
+        # self.assertEqual(a1.clan_edges()[0], NetworkEdge.objects.get(parent=a1, child=b2))
+        # log.debug("CLAN: ", str(a1.clan_edges()))
+        # self.assertEqual(a1.clan_edges()[1], NetworkEdge.objects.get(parent=a1, child=b1))
 
         log.debug("shortest_path x2")
         self.assertTrue(
